@@ -8,11 +8,10 @@ what kind of store and serializer to use.
 """
 
 
-from tiddlyweb.web.negotiate import Negotiate
+from tiddlyweb.web.negotiate import figure_type
 from tiddlyweb.config import config
 
 def setup_module(module):
-    module.neg = Negotiate(lambda x: x)
     module.environ = {'tiddlyweb.config': config}
     environ['REQUEST_METHOD'] = 'GET'
 
@@ -21,30 +20,39 @@ def test_accept_header():
     Given an accept header in the environ,
     determine the type we want.
     """
-    environ['HTTP_ACCEPT'] = 'text/plain; q=1.0, text/html, text/x-dvi; q=0.8, text/x-c'
+    environ['HTTP_ACCEPT'] = 'text/plain; q=1.0, text/html; q=0.9, text/x-dvi; q=0.8, text/x-c'
 
-    neg.figure_type(environ)
+    figure_type(environ)
 
-    assert environ['tiddlyweb.type'][0] == 'text/plain', \
-            'tiddlyweb.type should be text/plain, found %s' % environ['tiddlyweb.type'][0]
+    assert environ['tiddlyweb.type'][0] == 'text/plain'
 
 def test_accept_ill_formed_header():
     """
     Given an accept header in the environ,
-    that is poorly formed, properly skip over a bad entry.
+    that is poorly formed, use default.
     """
     environ['HTTP_ACCEPT'] = '; q=1.0, text/plain; q=1.0, text/html, text/x-dvi; q=0.8, text/x-c'
 
-    neg.figure_type(environ)
+    figure_type(environ)
 
-    assert environ['tiddlyweb.type'][0] == 'text/plain'
+    assert environ['tiddlyweb.type'][0] == 'text/html'
+
+def test_accept_bad_q():
+    """
+    Given a non-float q, ignore.
+    """
+    environ['HTTP_ACCEPT'] = 'text/plain; q=hot, text/html, text/postscript; q=0.5'
+
+    figure_type(environ)
+
+    assert environ['tiddlyweb.type'][0] == 'text/html'
 
 def test_accept_extension():
     """
     Ignore non q= style parameters.
     """
     environ['HTTP_ACCEPT'] = 'text/plain; cookies=chip'
-    neg.figure_type(environ)
+    figure_type(environ)
     assert environ['tiddlyweb.type'][0] == 'text/plain'
 
 def test_file_extension():
@@ -54,7 +62,7 @@ def test_file_extension():
     """
     environ['PATH_INFO'] = '/bags/bag0/tiddlers/bigbox.html'
     
-    neg.figure_type(environ)
+    figure_type(environ)
 
     assert environ['tiddlyweb.type'][0] == 'text/html', \
             'tiddlyweb.type should be text/html, found %s' % environ['tiddlyweb.type'][0]
@@ -67,7 +75,7 @@ def test_file_wins_over_header():
     environ['HTTP_ACCEPT'] = 'text/plain; q=1.0, text/html, text/x-dvi; q=0.8, text/x-c'
     environ['PATH_INFO'] = '/bags/bag0/tiddlers/bigbox.html'
 
-    neg.figure_type(environ)
+    figure_type(environ)
 
     assert environ['tiddlyweb.type'][0] == 'text/html', \
             'tiddlyweb.type should be text/html, found %s' % environ['tiddlyweb.type'][0]
