@@ -58,9 +58,10 @@ class Tiddler(object):
               have any assocation with the tiddlyweb.usersign,
               though it may.
     tags: A list of strings that describe the tiddler.
-    fields: An arbitrary dictionary of extended fields on the tiddler.
+    fields: An arbitrary dictionary of extended (custom) fields on the tiddler.
     text: The contents of the tiddler. A string.
-    revision: The revision of this tiddler. An int.
+    revision: The revision of this tiddler. The type of a revision
+              is unspecified.
     bag: The name of the bag in which this tiddler exists,
          if any. Usually set by internal code.
     recipe: The name of the recipe in which this tiddler exists,
@@ -69,19 +70,17 @@ class Tiddler(object):
            this tiddler from persistent storage.
     """
 
-    slots = ['title',
-            'created',
-            'modified',
-            'modifier',
+    data_members = ['title',
             'creator',
+            'created',
+            'modifier',
+            'modified',
             'tags',
             'fields',
-            'text',
             'type',
-            'revision',
-            'bag',
-            'recipe',
-            'store']
+            'text']
+    # TiddlyWeb-specific attributes
+    slots = data_members + ['revision', 'bag', 'recipe', 'store']
 
     def __init__(self, title=None, bag=None):
         """
@@ -104,7 +103,7 @@ class Tiddler(object):
         self.fields = {}
         self.text = u''
         self.type = None
-        self.revision = 0
+        self.revision = None
         self.recipe = None
         # reference to the store which 'got' us
         self.store = None
